# ansible-compat

```{include} examples.md

```

## API

```{eval-rst}
.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. automodule:: ansible_compat.runtime
.. autoclass:: Runtime
   :members:
   :special-members: __init__
```
